@@ -51,7 +51,7 @@ def get_items(client: list[TonlibClient] or TonlibClient, addresses: list, filen
         tasks = []
         for addr in addresses[i * max_requests:min(len(addresses), max_requests * (i + 1))]:
             tasks.append(get_item(client[d % len(client)], addr, nft_items, items))
-            print(d % len(client))
+            # print(d % len(client))
             d += 1
         asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
         print('DONE')
